split_suffix

Function split_suffix 

fn split_suffix(data: &[u8]) -> Option<(&[u8], u8, &[u8])>
Splits a trailing ERC-8021 attribution suffix off the given calldata, returning the calldata before it, the schema id and the schema data.